@@ -47,14 +47,14 @@ MainWindow::MainWindow(const QCommandLineParser &arg_parser, QWidget *parent)
       ui(new Ui::MainWindow),
       file_location {"/etc/custom-toolbox"}
 {
-
     ui->setupUi(this);
     setConnections();
+
     if (arg_parser.isSet("remove-checkbox")) {
         ui->checkBoxStartup->hide();
     }
 
-    setWindowFlags(Qt::Window); // For the close, min and max buttons
+    setWindowFlags(Qt::Window); // Enable close, minimize, and maximize buttons
     setup();
 
     const QStringList argList = arg_parser.positionalArguments();
@@ -69,79 +69,93 @@ MainWindow::~MainWindow()
     delete ui;
 }
 
-QIcon MainWindow::findIcon(const QString &icon_name)
+QIcon MainWindow::findIcon(const QString &iconName)
 {
-    static QIcon defaultIcon;
-    static bool defaultIconLoaded = false;
-
-    if (icon_name.isEmpty()) {
-        if (!defaultIconLoaded) {
-            defaultIcon = findIcon("utilities-terminal");
-            defaultIconLoaded = true;
-        }
-        return defaultIcon;
-    }
-
-    // Check if the icon name is an absolute path and exists
-    if (QFileInfo(icon_name).isAbsolute() && QFile::exists(icon_name)) {
-        return QIcon(icon_name);
-    }
-
-    // Prepare regular expression to strip extension
     static const QRegularExpression re(R"(\.(png|svg|xpm)$)");
-    QString name_noext = icon_name;
-    name_noext.remove(re);
+    static const QStringList extensions {".png", ".svg", ".xpm"};
+    static const QStringList searchPaths {QDir::homePath() + "/.local/share/icons/",
+                                          "/usr/share/pixmaps/",
+                                          "/usr/local/share/icons/",
+                                          "/usr/share/icons/",
+                                          "/usr/share/icons/hicolor/scalable/apps/",
+                                          "/usr/share/icons/hicolor/48x48/apps/",
+                                          "/usr/share/icons/Adwaita/48x48/legacy/"};
+
+    // Helper function to search for icon in all paths
+    static const auto searchInPaths = [&](const QString &name) -> QIcon {
+        for (const auto &path : searchPaths) {
+            const QString fullPath = QDir(path).filePath(name);
+            if (QFile::exists(fullPath)) {
+                QIcon icon(fullPath);
+                if (!icon.isNull()) {
+                    return icon;
+                }
+            }
+        }
+        return QIcon();
+    };
+
+    // Initialize default terminal icon once when needed
+    static const auto getDefaultIcon = []() {
+        static QIcon defaultIcon;
+        if (!defaultIcon.isNull()) {
+            return defaultIcon;
+        }
+
+        const QString defaultIconName = "utilities-terminal";
+        defaultIcon = QIcon::fromTheme(defaultIconName);
+        if (!defaultIcon.isNull()) {
+            return defaultIcon;
+        }
+
+        for (const auto &ext : extensions) {
+            defaultIcon = searchInPaths(defaultIconName + ext);
+            if (!defaultIcon.isNull()) {
+                return defaultIcon;
+            }
+        }
+        return QIcon();
+    };
+
+    // Handle empty or default icon name
+    if (iconName.isEmpty() || iconName == "utilities-terminal") {
+        return getDefaultIcon();
+    }
+
+    // Handle absolute paths
+    if (QFileInfo::exists(iconName) && QFileInfo(iconName).isAbsolute()) {
+        return QIcon(iconName);
+    }
+
+    // Try themed icon first
+    QString nameNoExt = iconName;
+    nameNoExt.remove(re);
 
-    // Set icon theme if specified
     if (!icon_theme.isEmpty()) {
         QIcon::setThemeName(icon_theme);
     }
 
-    // Return the themed icon if available
-    if (QIcon::hasThemeIcon(name_noext)) {
-        return QIcon::fromTheme(name_noext);
+    QIcon icon = QIcon::fromTheme(nameNoExt);
+    if (!icon.isNull()) {
+        return icon;
     }
 
-    // Define common search paths for icons
-    QStringList search_paths {QDir::homePath() + "/.local/share/icons/",
-                              "/usr/share/pixmaps/",
-                              "/usr/local/share/icons/",
-                              "/usr/share/icons/",
-                              "/usr/share/icons/hicolor/scalable/apps/",
-                              "/usr/share/icons/hicolor/48x48/apps/",
-                              "/usr/share/icons/Adwaita/48x48/legacy/"};
-
-    // Optimization: search first for the full icon_name with the specified extension
-    auto it = std::find_if(search_paths.cbegin(), search_paths.cend(),
-                           [&](const QString &path) { return QFile::exists(path + icon_name); });
-    if (it != search_paths.cend()) {
-        return QIcon(*it + icon_name);
+    // Try original name
+    icon = searchInPaths(iconName);
+    if (!icon.isNull()) {
+        return icon;
     }
 
-    // Search for the icon without extension in the specified paths
-    for (const QString &path : search_paths) {
-        if (!QFile::exists(path)) {
-            continue;
-        }
-        for (const char *ext : {".png", ".svg", ".xpm"}) {
-            QString file = path + name_noext + ext;
-            if (QFile::exists(file)) {
-                return QIcon(file);
-            }
+    // Try with each extension
+    for (const auto &ext : extensions) {
+        icon = searchInPaths(nameNoExt + ext);
+        if (!icon.isNull()) {
+            return icon;
         }
     }
 
-    // If the icon is "utilities-terminal" and not found, return the default icon if it's already loaded
-    if (icon_name == "utilities-terminal") {
-        if (!defaultIconLoaded) {
-            defaultIcon = QIcon();
-            defaultIconLoaded = true;
-        }
-        return defaultIcon;
-    }
-
-    // If the icon is not "utilities-terminal", try to load the default icon
-    return findIcon("utilities-terminal");
+    // Fall back to the default icon if nothing else was found.
+    return getDefaultIcon();
 }
 
 // Strip %f, %F, %U, etc. if exec expects a file name since it's called without an argument from this launcher.
@@ -152,8 +166,11 @@ void MainWindow::fixExecItem(QString *item)
 
 void MainWindow::fixNameItem(QString *item)
 {
-    if (*item == "System Profiler and Benchmark") {
-        *item = "System Information";
+    static const QString oldName = "System Profiler and Benchmark";
+    static const QString newName = "System Information";
+
+    if (*item == oldName) {
+        *item = newName;
     }
 }
 
@@ -165,7 +182,7 @@ void MainWindow::setup()
     const int default_icon_size = 40;
 
     QSettings settings("/etc/custom-toolbox/custom-toolbox.conf", QSettings::NativeFormat);
-    hideGUI = settings.value("hideGUI", "false").toBool();
+    hideGUI = settings.value("hideGUI", false).toBool();
     min_height = settings.value("min_height").toInt();
     min_width = settings.value("min_width").toInt();
     gui_editor = settings.value("gui_editor").toString();
@@ -209,12 +226,17 @@ void MainWindow::btn_clicked()
     // pkexec cannot take &, it would block the GUI that's why we need to hide it
     if (hideGUI || cmd.startsWith("pkexec")) {
         hide();
-        system(cmd.toUtf8());
+        int exitCode = system(cmd.toUtf8());
+        if (exitCode == -1) {
+            QMessageBox::warning(this, tr("Execution Error"), tr("Failed to execute command: %1").arg(cmd));
+        }
         show();
     } else {
         QStringList arguments = QProcess::splitCommand(cmd);
         QString program = arguments.takeFirst();
-        QProcess::startDetached(program, arguments);
+        if (!QProcess::startDetached(program, arguments)) {
+            QMessageBox::warning(this, tr("Execution Error"), tr("Failed to start program: %1").arg(program));
+        }
     }
 }
 
@@ -275,22 +297,19 @@ QString MainWindow::getFileName()
 QString MainWindow::getDesktopFileName(const QString &appName) const
 {
     // Search for .desktop files in standard applications locations
-    QStringList searchPaths = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
-    searchPaths.append(defaultPath); // Include default path for executable search
+    const QStringList searchPaths = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
 
+    // Search for .desktop file in each path
+    const QString desktopFileName = appName + ".desktop";
     for (const QString &searchPath : searchPaths) {
-        QDir searchDir(searchPath);
-        QStringList desktopFiles = searchDir.entryList({appName + ".desktop"}, QDir::Files, QDir::NoSort);
-        if (!desktopFiles.isEmpty()) {
-            return searchDir.absoluteFilePath(desktopFiles.first());
+        const QString fullPath = QDir(searchPath).absoluteFilePath(desktopFileName);
+        if (QFile::exists(fullPath)) {
+            return fullPath;
         }
     }
     // If .desktop file not found, fallback to finding the executable
-    QString executablePath = QStandardPaths::findExecutable(appName, {defaultPath});
-    if (!executablePath.isEmpty()) {
-        return QFileInfo(executablePath).fileName(); // Return just the executable name
-    }
-    return {};
+    const QString executablePath = QStandardPaths::findExecutable(appName, {defaultPath});
+    return !executablePath.isEmpty() ? QFileInfo(executablePath).fileName() : QString();
 }
 
 // Return the app info needed for the button
@@ -484,7 +503,6 @@ void MainWindow::processLine(const QString &line)
 // Open the .list file and process it
 void MainWindow::readFile(const QString &file_name)
 {
-    // Reset categories and category_map when reloading the file
     categories.clear();
     category_map.clear();
 
@@ -543,12 +561,9 @@ QString MainWindow::extractPattern(const QString &text, const QString &key)
     re.setPattern(fallbackPattern);
     match = re.match(text);
 
-    if (match.hasMatch()) {
-        return match.captured(1);
-    }
-
-    return QString();
+    return match.hasMatch() ? match.captured(1) : QString();
 }
+
 void MainWindow::setConnections()
 {
     connect(ui->checkBoxStartup, &QPushButton::clicked, this, &MainWindow::checkBoxStartup_clicked);
@@ -562,14 +577,17 @@ void MainWindow::setConnections()
 void MainWindow::pushAbout_clicked()
 {
     hide();
-    displayAboutMsgBox(
-        tr("About %1").arg(windowTitle()),
-        "<p align=\"center\"><b><h2>" + windowTitle() + "</h2></b></p><p align=\"center\">" + tr("Version: ") + VERSION
-            + "</p><p align=\"center\"><h3>" + tr("Custom Toolbox is a tool used for creating a custom launcher")
-            + "</h3></p><p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br /></p>"
-              "<p align=\"center\">"
-            + tr("Copyright (c) MX Linux") + "<br /><br /></p>",
-        "/usr/share/doc/custom-toolbox/license.html", tr("%1 License").arg(windowTitle()));
+    QString aboutText
+        = QString("<p align=\"center\"><b><h2>%1</h2></b></p>"
+                  "<p align=\"center\">%2 %3</p>"
+                  "<p align=\"center\"><h3>%4</h3></p>"
+                  "<p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br /></p>"
+                  "<p align=\"center\">%5<br /><br /></p>")
+              .arg(windowTitle(), tr("Version:"), VERSION,
+                   tr("Custom Toolbox is a tool used for creating a custom launcher"), tr("Copyright (c) MX Linux"));
+
+    displayAboutMsgBox(tr("About %1").arg(windowTitle()), aboutText, "/usr/share/doc/custom-toolbox/license.html",
+                       tr("%1 License").arg(windowTitle()));
     show();
 }
 
@@ -650,25 +668,23 @@ QString MainWindow::getDefaultEditor()
         = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, default_editor, QStandardPaths::LocateFile);
 
     if (desktop_file.isEmpty()) {
-        return "nano"; // Use nano as backup editor
+        return "nano"; // Fallback to nano
     }
 
     QFile file(desktop_file);
     if (!file.open(QIODevice::ReadOnly)) {
-        return "nano"; // Use nano as backup editor
+        return "nano"; // Fallback to nano
     }
 
     QTextStream in(&file);
     QString line;
     while (in.readLineInto(&line)) {
         if (line.startsWith("Exec=")) {
-            file.close();
             return line.remove(QRegularExpression("^Exec=|%u|%U|%f|%F|%c|%C|-b")).trimmed();
         }
     }
 
-    file.close();
-    return "nano"; // Use nano as backup editor
+    return "nano"; // Fallback to nano
 }
 
 QStringList MainWindow::buildEditorCommand(const QString &editor)
